﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using Microsoft.Xna.Framework.Media;

namespace MediaPlayerDemo
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Set fields of appbar buttons; otherwise they're null
            playButton = this.ApplicationBar.Buttons[0] as ApplicationBarIconButton;
            pauseButton = this.ApplicationBar.Buttons[1] as ApplicationBarIconButton;

            // Set MediaPlayer event
            MediaPlayer.MediaStateChanged += OnMediaPlayerStateChanged;

            // Update the elapsed time and slider position
            CompositionTarget.Rendering += (sender, args) =>
            {
                elapsedTime.Text = MediaPlayer.PlayPosition.ToString("m\\:ss\\.f");
                mediaState.Text = MediaPlayer.State.ToString();
            };
        }

        void OnRadioButtonChecked(object sender, RoutedEventArgs args)
        {
            RadioButton radio = sender as RadioButton;
            string uriString = radio.Tag as string;
            Uri uri = new Uri(uriString, uriString.Contains(':') ? UriKind.Absolute : UriKind.Relative);
            Song song = Song.FromUri("song", uri);
            MediaPlayer.Play(song);
        }

        void OnMediaPlayerStateChanged(object sender, EventArgs args)
        {
            switch (MediaPlayer.State)
            {
                case MediaState.Playing:
                    playButton.IsEnabled = false;
                    pauseButton.IsEnabled = true;
                    break;

                case MediaState.Paused:
                case MediaState.Stopped:
                    playButton.IsEnabled = true;
                    pauseButton.IsEnabled = false;
                    break;

                default:
                    playButton.IsEnabled = false;
                    pauseButton.IsEnabled = false;
                    break;
            }
        }

        void OnPlayButtonClick(object sender, EventArgs args)
        {
            MediaPlayer.Resume();
        }

        void OnPauseButtonClick(object sender, EventArgs args)
        {
            MediaPlayer.Pause();
        }
    }
}